﻿using System;
using System.Activities.Presentation.Metadata;
using System.Diagnostics;
using UiPath.Studio.Activities.Api;

namespace MyCustomActivityPack
{
    public class RegisterMetadata : IRegisterMetadata
    {
        public void Register()
        {
            var builder = new AttributeTableBuilder();
            SampleActivityDesigner.RegisterMetadata(builder);
            MetadataStore.AddAttributeTable(builder.CreateTable());
        }

        /// <summary>
        /// This method is discovered in Studio using reflection.
        /// If found, a reference to the studio api is passed
        public void Initialize(object argument)
        {
            try
            {
                var api = argument as IWorkflowDesignApi;
                if (api == null)
                {
                    return;
                }

                if (api.HasFeature(DesignFeatureKeys.Settings))
                {
                    // when using various features available in the API
                    // please check the comments for "Requires Feature X".
                    // If the version of Studio that is currently executing doesn't have the feature,
                    // attempting to access that feature will result in a runtime error.

                    // It is VERY IMPORTANT to have the code that is using a feature in a different method
                    // than the one that checked if a feature is available.
                    // This prevents the JIT compile step of the method that is using the feature BEFORE the feature check.
                    SettingsCreator.CreateSettings(api);
                }
                
                if (api.HasFeature(DesignFeatureKeys.Settings))
                {
                    WizardCreator.CreateWizards(api);
                }
                
            }
            catch (Exception ex)
            {
                Trace.TraceError(ex.Message);
            }
        }
    }
}