﻿using System.Activities;
using System.Diagnostics;
using System.Text;
using System.Windows;
using UiPath.Robot.Activities.Api;

namespace MyCustomActivityPack
{
    public sealed class SampleActivity : NativeActivity
    {
        protected override void Execute(NativeActivityContext context)
        {
            var api = context.GetExtension<IExecutorRuntime>();
            if (api == null)
            {
                Trace.WriteLine("Studio API is not available for the current Executor version");
                return;
            }

            if (!api.HasFeature(ExecutorFeatureKeys.Settings))
            {
                Trace.WriteLine("Studio Settings API is not available for the current Executor version");
                // when using various features available in the API
                // please check the comments for "Requires Feature X".
                // If the version of Studio that is currently executing doesn't have the feature,
                // attempting to access that feature will result in a runtime error.
                return;
            }

            // It is VERY IMPORTANT to have the code that is using a feature in a different method
            // than the one that checked if a feature is available.
            // This prevents the JIT compile step of the method that is using the feature BEFORE the feature check.
            DisplaySettingsValues(api);
        }

        private static void DisplaySettingsValues(IExecutorRuntime api)
        {
            StringBuilder sb = new StringBuilder();
            if (api.Settings.TryGetValue(SettingsCreator.CommentTextKey, out string comment))
            {
                sb.AppendLine($"{SettingsCreator.CommentTextKey}: {comment}");
            }

            sb.AppendLine();

            if (api.Settings.TryGetValue(SettingsCreator.ShuffleKey, out bool shuffle))
            {
                sb.AppendLine($"{SettingsCreator.ShuffleKey}: {shuffle}");
            }

            if (api.Settings.TryGetValue(SettingsCreator.PresetKey, out string preset))
            {
                sb.AppendLine($"{SettingsCreator.PresetKey}: {preset}");
            }

            MessageBox.Show(sb.ToString(), "Sample Activity", MessageBoxButton.OK, MessageBoxImage.Information);
        }
    }
}