﻿using System.Activities.Presentation;
using System.Activities.Presentation.Metadata;
using System.ComponentModel;
using System.Windows;
using UiPath.Studio.Activities.Api;

namespace MyCustomActivityPack
{
    /// <summary>
    /// Interaction logic for SampleActivityDesigner.xaml
    /// </summary>
    public partial class SampleActivityDesigner : ActivityDesigner
    {
        public SampleActivityDesigner()
        {
            InitializeComponent();
            Loaded += OnDesignerLoaded;
        }

        public static void RegisterMetadata(AttributeTableBuilder builder)
        {
            builder.AddCustomAttributes(typeof(SampleActivity), new DesignerAttribute(typeof(SampleActivityDesigner)));
            builder.AddCustomAttributes(typeof(SampleActivity), new DescriptionAttribute("Studio API Sample Activity"));
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            DisplaySettingsValues();
        }

        private void DisplaySettings(IWorkflowDesignApi api)
        {
            if (api.Settings.TryGetValue(SettingsCreator.ShuffleKey, out bool shuffle))
            {
                SettingsList.Items.Add($"Shuffle: {shuffle}");
            }

            if (api.Settings.TryGetValue(SettingsCreator.PresetKey, out string preset))
            {
                SettingsList.Items.Add($"Mixer Preset: {preset}");
            }

            if (api.Settings.TryGetValue(SettingsCreator.CommentTextKey, out string comment))
            {
                SettingsList.Items.Add($"Comment: {comment}");
            }
        }

        private void DisplaySettingsValues()
        {
            // keep the sample simple (no view model)
            SettingsList.Items.Clear();
            var api = Context.Services.GetService<IWorkflowDesignApi>();
            if (api == null)
            {
                System.Diagnostics.Trace.WriteLine("Studio API is not available for the current Studio version");
                return;
            }

            if (!api.HasFeature(DesignFeatureKeys.Settings))
            {
                System.Diagnostics.Trace.WriteLine("Studio Settings API is not available for the current Executor version");
                return;
            }

            DisplaySettings(api);
        }

        private void OnDesignerLoaded(object sender, System.Windows.RoutedEventArgs e)
        {
            DisplaySettingsValues();
        }
    }
}